==> yos.core-1.0.0-sources.jar: restcontroller/sysmanage/develop/apidoc/apidoc.java <==
package restcontroller.sysmanage.develop.apidoc;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.parser.Feature;
import common.Controller;
import common.YosException;
import common.annotation.API;
import common.annotation.CACHEING;
import common.annotation.CACHEING_CLEAN;
import common.annotation.cm;
import common.api.YOSAPI;
import common.data.Row;
import common.data.Rows;
import common.data.SQLFactory;
import common.parameter.parameter;
import utility.tools.Encryption;

import java.util.Calendar;
import java.util.HashMap;

public class apidoc extends Controller {
    public apidoc(JSONObject content) throws YosException {
        super(content);
    }

    @API(title = "应用api-应用列表查询")
    @CACHEING
    public String queryAppList() throws YosException {
        /**
         * 过滤条件设置
         */
        StringBuffer where = new StringBuffer(" 1=1 ");
        if (content.containsKey("where")) {
            JSONObject whereObject = content.getJSONObject("where");
            if (whereObject.containsKey("condition") && !"".equals(whereObject.getString("condition"))) {
                where.append(" and(");
                where.append("t4.systemappname like'%").append(whereObject.getString("condition")).append("%' ");
                where.append("or t3.systemmodulename like'%").append(whereObject.getString("condition")).append("%' ");
                where.append("or t1.systemname like'%").append(whereObject.getString("condition")).append("%' ");
                where.append(")");
            }
        }
        SQLFactory sqlFactory = new SQLFactory(this, "应用列表查询", pageSize, pageNumber, pageSorting);
        sqlFactory.addParameter_SQL("where", where);
        Rows rows = dbConnect.runSqlQuery(sqlFactory.getSQL());
        for (Row row : rows) {
            row.put("tablecount", dbConnect.runSqlQuery("select distinct table_name from sys_objectapps where systemappid=" + row.getLong("systemappid")).size());
            row.put("apicount", dbConnect.runSqlQuery("select distinct apiid,apiversion from sys_apiapps where systemappid=" + row.getLong("systemappid")).size());
        }
        return getSucReturnObject().setData(rows).toString();
    }

    @API(title = "应用api-应用关联数据表查询")
    @CACHEING
    public String queryAppTableList() throws YosException {
        long systemappid = content.getLong("systemappid");
        SQLFactory sqlFactory = new SQLFactory(this, "应用关联数据表查询");
        sqlFactory.addParameter("systemappid", systemappid);
        Rows rows = dbConnect.runSqlQuery(sqlFactory.getSQL());
        return getSucReturnObject().setData(rows).toString();
    }

    @API(title = "应用api-应用关联数据表添加")
    @CACHEING_CLEAN(cms = {@cm(clazz = apidoc.class, method = {"queryAppTableList", "queryAppList"})})
    public String addAppTable() throws YosException {
        long systemappid = content.getLong("systemappid");
        String table_name = content.getString("table_name");

        SQLFactory sqlFactory = new SQLFactory(this, "数据表关联应用添加");
        sqlFactory.addParameter("sys_objectappsid", createTableID("sys_objectapps"));
        sqlFactory.addParameter("systemappid", systemappid);
        sqlFactory.addParameter("table_name", table_name);
        dbConnect.runSqlUpdate(sqlFactory.getSQL());
        return getSucReturnObject().toString();
    }

    @API(title = "应用api-应用关联数据表删除")
    @CACHEING_CLEAN(cms = {@cm(clazz = apidoc.class, method = {"queryAppTableList", "queryAppList"})})
    public String deleteAppTable() throws YosException {
        String sys_objectappsid = content.getString("sys_objectappsid");
        dbConnect.runSqlUpdate("delete from sys_objectapps where sys_objectappsid=" + sys_objectappsid);
        return getSucReturnObject().toString();
    }

    @API(title = "应用api-应用关联接口查询")
    public String queryAppApiList() throws YosException {
        long systemappid = content.getLong("systemappid");
        SQLFactory sqlFactory = new SQLFactory(this, "应用关联API查询");
        sqlFactory.addParameter("systemappid", systemappid);
        Rows rows = dbConnect.runSqlQuery(sqlFactory.getSQL());
        HashMap<String, String> codermap = getOptionType("coder");
        for (Row row : rows) {
            long apiid = row.getLong("apiid");
            int apiversion = row.getInteger("apiversion");
            Rows apidocrows = dbConnect.runSqlQuery("select requestjson,requestnotes,responsejson,responsenotes from sys_apidoc where apiid='" + apiid + "' and apiversion='" + apiversion + "'");
            if (apidocrows.isEmpty()) {
                JSONObject requestjsonObject = new JSONObject();
                requestjsonObject.put("accesstoken", Encryption.Encode_MD5(String.valueOf(Calendar.getInstance().getTimeInMillis())));
                requestjsonObject.put("id", apiid);
                requestjsonObject.put("content", new JSONObject());

                row.put("requestjson", requestjsonObject);
                row.put("responsejson", new JSONObject());
                row.put("requestnotes", "");
                row.put("responsenotes", "");
            } else {
                row.put("requestjson", apidocrows.get(0).getJSONObject("requestjson"));
                row.put("responsejson", apidocrows.get(0).getJSONObject("responsejson"));
                row.put("requestnotes", apidocrows.get(0).getString("requestnotes"));
                row.put("responsenotes", apidocrows.get(0).getString("responsenotes"));
            }
            if (apiid > 0) {
                String apiid_str = String.valueOf(apiid);
                row.put("coder", codermap.getOrDefault(apiid_str.substring(apiid_str.length() - 2), ""));
            } else {
                row.put("coder", "");
            }

            try {
                YOSAPI yosapi = YOSAPI.getApi(apiid, apiversion);
                API api = yosapi.getApi();
                String classtitle = "";

                Class clazz = yosapi.getClazz();
                if (clazz.isAnnotationPresent(API.class)) {
                    classtitle = ((API) clazz.getAnnotation(API.class)).title();
                }
                row.put("classname", clazz.getName().replace("restcontroller.", ""));
                row.put("method", yosapi.getMethod().getName());
                row.put("classtitle", classtitle);
                row.put("title", api.title());
                row.put("notes", api.notes());
                row.put("deprecated", api.deprecated() ? 1 : 0);
                row.put("intervaltime", api.intervaltime());
                row.put("intervaltime_active", yosapi.getApiIntervaltime());
                row.put("accesstoken", api.accesstoken());
                row.put("cacheinglife", yosapi.getCacheing() == null ? "" : yosapi.getCacheing().life());

                String key = clazz.getName() + "." + yosapi.getMethod().getName();
                JSONObject requestmsg = new JSONObject();
                requestmsg.put("requesttimes", parameter.callmethodTimes.getOrDefault(key, 0L));//请求次数
                requestmsg.put("readcachetimes", parameter.callmethod_fromcacheTimes.getOrDefault(key, 0L));//缓存读取次数
                requestmsg.put("requesttimelong_last", parameter.callmethodLastTimeLong.getOrDefault(key, 0L));//最新请求时长
                requestmsg.put("requesttimelong_avg", parameter.callmethodTimeLong.getOrDefault(key, 0L));//请求平均时长
                if (parameter.lastcallmethodtime.containsKey(key)) {
                    requestmsg.put("lastrequesttime", getDateTime_Str(parameter.lastcallmethodtime.get(key)));//最新请求时间
                } else {
                    requestmsg.put("lastrequesttime", "");//最新请求时间
                }
                row.put("requestmsg", requestmsg);
            } catch (YosException e) {
                e.printStackTrace();
                row.put("classtitle", "");
                row.put("classname", "");
                row.put("method", "");
                row.put("title", "");
                row.put("notes", "");
                row.put("intervaltime", "");
                row.put("intervaltime_active", "");
                row.put("accesstoken", "");
                row.put("cacheinglife", "");
                JSONObject requestmsg = new JSONObject();
                requestmsg.put("requesttimes", 0);//请求次数
                requestmsg.put("readcachetimes", 0);//缓存读取次数
                requestmsg.put("requesttimelong_last", 0);//最新请求时长
                requestmsg.put("requesttimelong_avg", 0);//请求平均时长
                requestmsg.put("lastrequesttime", "");//接口最新请求时间
                row.put("requestmsg", requestmsg);
            }
        }
        return getSucReturnObject().setData(rows).toString();
    }


    @API(title = "应用api-应用关联Api添加")
    @CACHEING_CLEAN(cms = {@cm(clazz = apidoc.class, method = {"queryAppApiList", "queryAppList"})})
    public String addAppApi() throws YosException {
        long systemappid = content.getLong("systemappid");
        long apiid = content.getLong("apiid");
        int apiversion = content.getIntValue("apiversion") > 0 ? content.getIntValue("apiversion") : 1;
        SQLFactory sqlFactory = new SQLFactory(this, "Api关联应用添加");
        sqlFactory.addParameter("sys_apiappsid", createTableID("sys_apiapps"));
        sqlFactory.addParameter("systemappid", systemappid);
        sqlFactory.addParameter("apiid", apiid);
        sqlFactory.addParameter("apiversion", apiversion);
        dbConnect.runSqlUpdate(sqlFactory.getSQL());
        return getSucReturnObject().toString();
    }

    @API(title = "应用api-应用关联Api删除")
    @CACHEING_CLEAN(cms = {@cm(clazz = apidoc.class, method = {"queryAppApiList"})})
    public String deleteAppApi() throws YosException {
        long sys_apiappsid = content.getLong("sys_apiappsid");
        dbConnect.runSqlUpdate("delete from sys_apiapps where sys_apiappsid=" + sys_apiappsid);
        return getSucReturnObject().toString();
    }

    @API(title = "应用api-Api文档更新")
    @CACHEING_CLEAN(cms = {@cm(clazz = apidoc.class, method = {"queryAppApiList", "queryAppList"})})
    public String updateApiDoc() throws YosException {
        long apiid = content.getLongValue("apiid");
        int apiversion = content.getIntValue("apiversion");

        JSONObject requestjson = null;
        try {
            requestjson = JSONObject.parseObject(content.getString("requestjson", true), Feature.OrderedField);
        } catch (Exception e) {
            return getErrReturnObject().setErrMsg("请求内容不是有效的JSONObject格式").toString();
        }
        JSONObject responsejson;
        try {
            responsejson = JSONObject.parseObject(content.getString("responsejson"), Feature.OrderedField);
        } catch (Exception e) {
            return getErrReturnObject().setErrMsg("响应内容不是有效的JSONObject格式").toString();
        }

        String requestnotes = content.getString("requestnotes");
        String responsenotes = content.getString("responsenotes");

        if (dbConnect.runSqlQuery("select * from sys_apidoc where apiid='" + apiid + "' and apiversion='" + apiversion + "'").isEmpty()) {
            SQLFactory sqlFactory = new SQLFactory(this, "Api文档新增");
            sqlFactory.addParameter("sys_apidocid", createTableID("sys_apidoc"));
            sqlFactory.addParameter("apiid", apiid);
            sqlFactory.addParameter("apiversion", apiversion);
            sqlFactory.addParameter("requestjson", requestjson.toJSONString());
            sqlFactory.addParameter("requestnotes", requestnotes);
            sqlFactory.addParameter("responsejson", responsejson.toJSONString());
            sqlFactory.addParameter("responsenotes", responsenotes);
            sqlFactory.addParameter("changeuserid", userid);
            dbConnect.runSqlUpdate(sqlFactory.getSQL());
        } else {
            dbConnect.runSqlUpdate("update sys_apidoc set changedate=now(),changeuserid='" + userid + "', requestjson='" + requestjson.toJSONString() + "',requestnotes='" + requestnotes + "', responsejson='" + responsejson.toJSONString() + "',responsenotes='" + responsenotes + "' where apiid='" + apiid + "' and apiversion='" + apiversion + "'");
        }
        return getSucReturnObject().toString();
    }
}

==> yos.core-2.2.4-sources.jar: restcontroller/sysmanage/develop/apidoc/apidoc.java <==
package restcontroller.sysmanage.develop.apidoc;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.parser.Feature;
import common.Controller;
import common.YosException;
import common.annotation.API;
import common.annotation.CACHEING;
import common.annotation.CACHEING_CLEAN;
import common.annotation.cm;
import common.api.YOSAPI;
import common.data.Row;
import common.data.Rows;
import common.data.SQLFactory;
import common.parameter.parameter;
import restcontroller.R;
import utility.tools.Encryption;

import java.util.Calendar;
import java.util.HashMap;

public class apidoc extends Controller {
    public apidoc(JSONObject content) throws YosException {
        super(content);
    }

    @API(title = "应用api-应用列表查询", apiversion = R.ID10003501.v1.class)
    @CACHEING
    public String queryAppList() throws YosException {
        /**
         * 过滤条件设置
         */
        StringBuffer where = new StringBuffer(" 1=1 ");
        if (content.containsKey("where")) {
            JSONObject whereObject = content.getJSONObject("where");
            if (whereObject.containsKey("condition") && !"".equals(whereObject.getString("condition"))) {
                where.append(" and(");
                where.append("t4.systemappname like'%").append(whereObject.getString("condition")).append("%' ");
                where.append("or t3.systemmodulename like'%").append(whereObject.getString("condition")).append("%' ");
                where.append("or t1.systemname like'%").append(whereObject.getString("condition")).append("%' ");
                where.append(")");
            }
        }
        SQLFactory sqlFactory = new SQLFactory(this, "应用列表查询", pageSize, pageNumber, pageSorting);
        sqlFactory.addParameter_SQL("where", where);
        Rows rows = dbConnect.runSqlQuery(sqlFactory.getSQL());
        for (Row row : rows) {
            row.put("tablecount", dbConnect.runSqlQuery("select distinct table_name from sys_objectapps where systemappid=" + row.getLong("systemappid")).size());
            row.put("apicount", dbConnect.runSqlQuery("select distinct apiid,apiversion from sys_apiapps where systemappid=" + row.getLong("systemappid")).size());
        }
        return getSucReturnObject().setData(rows).toString();
    }

    @API(title = "应用api-应用关联数据表查询", apiversion = R.ID10003601.v1.class)
    @CACHEING
    public String queryAppTableList() throws YosException {
        long systemappid = content.getLong("systemappid");
        SQLFactory sqlFactory = new SQLFactory(this, "应用关联数据表查询");
        sqlFactory.addParameter("systemappid", systemappid);
        Rows rows = dbConnect.runSqlQuery(sqlFactory.getSQL());
        return getSucReturnObject().setData(rows).toString();
    }

    @API(title = "应用api-应用关联数据表添加", apiversion = R.ID10003701.v1.class)
    @CACHEING_CLEAN(cms = {@cm(clazz = apidoc.class, method = {"queryAppTableList", "queryAppList"})})
    public String addAppTable() throws YosException {
        long systemappid = content.getLong("systemappid");
        String table_name = content.getString("table_name");

        SQLFactory sqlFactory = new SQLFactory(this, "数据表关联应用添加");
        sqlFactory.addParameter("sys_objectappsid", createTableID("sys_objectapps"));
        sqlFactory.addParameter("systemappid", systemappid);
        sqlFactory.addParameter("table_name", table_name);
        dbConnect.runSqlUpdate(sqlFactory.getSQL());
        return getSucReturnObject().toString();
    }

    @API(title = "应用api-应用关联数据表删除", apiversion = R.ID10003801.v1.class)
    @CACHEING_CLEAN(cms = {@cm(clazz = apidoc.class, method = {"queryAppTableList", "queryAppList"})})
    public String deleteAppTable() throws YosException {
        String sys_objectappsid = content.getString("sys_objectappsid");
        dbConnect.runSqlUpdate("delete from sys_objectapps where sys_objectappsid=" + sys_objectappsid);
        return getSucReturnObject().toString();
    }

    @API(title = "应用api-应用关联接口查询", apiversion = R.ID10003901.v1.class)
    public String queryAppApiList() throws YosException {
        long systemappid = content.getLong("systemappid");
        SQLFactory sqlFactory = new SQLFactory(this, "应用关联API查询");
        sqlFactory.addParameter("systemappid", systemappid);
        Rows rows = dbConnect.runSqlQuery(sqlFactory.getSQL());
        HashMap<String, String> codermap = getOptionType("coder");
        for (Row row : rows) {
            long apiid = row.getLong("apiid");
            int apiversion = row.getInteger("apiversion");
            Rows apidocrows = dbConnect.runSqlQuery("select requestjson,requestnotes,responsejson,responsenotes from sys_apidoc where apiid='" + apiid + "' and apiversion='" + apiversion + "'");
            if (apidocrows.isEmpty()) {
                JSONObject requestjsonObject = new JSONObject();
                requestjsonObject.put("accesstoken", Encryption.Encode_MD5(String.valueOf(Calendar.getInstance().getTimeInMillis())));
                requestjsonObject.put("id", apiid);
                requestjsonObject.put("content", new JSONObject());

                row.put("requestjson", requestjsonObject);
                row.put("responsejson", new JSONObject());
                row.put("requestnotes", "");
                row.put("responsenotes", "");
            } else {
                row.put("requestjson", apidocrows.get(0).getJSONObject("requestjson"));
                row.put("responsejson", apidocrows.get(0).getJSONObject("responsejson"));
                row.put("requestnotes", apidocrows.get(0).getString("requestnotes"));
                row.put("responsenotes", apidocrows.get(0).getString("responsenotes"));
            }
            if (apiid > 0) {
                String apiid_str = String.valueOf(apiid);
                row.put("coder", codermap.getOrDefault(apiid_str.substring(apiid_str.length() - 2), ""));
            } else {
                row.put("coder", "");
            }

            try {
                YOSAPI yosapi = YOSAPI.getApi(apiid, apiversion);
                API api = yosapi.getApi();
                String classtitle = "";

                Class clazz = yosapi.getClazz();
                if (clazz.isAnnotationPresent(API.class)) {
                    classtitle = ((API) clazz.getAnnotation(API.class)).title();
                }
                row.put("classname", clazz.getName().replace("restcontroller.", ""));
                row.put("method", yosapi.getMethod().getName());
                row.put("classtitle", classtitle);
                row.put("title", api.title());
                row.put("notes", api.notes());
                row.put("deprecated", api.deprecated() ? 1 : 0);
                row.put("intervaltime", api.intervaltime());
                row.put("intervaltime_active", yosapi.getApiIntervaltime());
                row.put("accesstoken", api.accesstoken());
                row.put("cacheinglife", yosapi.getCacheing() == null ? "" : yosapi.getCacheing().life());

                String key = clazz.getName() + "." + yosapi.getMethod().getName();
                JSONObject requestmsg = new JSONObject();
                requestmsg.put("requesttimes", parameter.callmethodTimes.getOrDefault(key, 0L));//请求次数
                requestmsg.put("readcachetimes", parameter.callmethod_fromcacheTimes.getOrDefault(key, 0L));//缓存读取次数
                requestmsg.put("requesttimelong_last", parameter.callmethodLastTimeLong.getOrDefault(key, 0L));//最新请求时长
                requestmsg.put("requesttimelong_avg", parameter.callmethodTimeLong.getOrDefault(key, 0L));//请求平均时长
                if (parameter.lastcallmethodtime.containsKey(key)) {
                    requestmsg.put("lastrequesttime", getDateTime_Str(parameter.lastcallmethodtime.get(key)));//最新请求时间
                } else {
                    requestmsg.put("lastrequesttime", "");//最新请求时间
                }
                row.put("requestmsg", requestmsg);
            } catch (YosException e) {
                e.printStackTrace();
                row.put("classtitle", "");
                row.put("classname", "");
                row.put("method", "");
                row.put("title", "");
                row.put("notes", "");
                row.put("intervaltime", "");
                row.put("intervaltime_active", "");
                row.put("accesstoken", "");
                row.put("cacheinglife", "");
                JSONObject requestmsg = new JSONObject();
                requestmsg.put("requesttimes", 0);//请求次数
                requestmsg.put("readcachetimes", 0);//缓存读取次数
                requestmsg.put("requesttimelong_last", 0);//最新请求时长
                requestmsg.put("requesttimelong_avg", 0);//请求平均时长
                requestmsg.put("lastrequesttime", "");//接口最新请求时间
                row.put("requestmsg", requestmsg);
            }
        }
        return getSucReturnObject().setData(rows).toString();
    }


    @API(title = "应用api-应用关联Api添加", apiversion = R.ID10004001.v1.class)
    @CACHEING_CLEAN(cms = {@cm(clazz = apidoc.class, method = {"queryAppApiList", "queryAppList"})})
    public String addAppApi() throws YosException {
        long systemappid = content.getLong("systemappid");
        long apiid = content.getLong("apiid");
        int apiversion = content.getIntValue("apiversion") > 0 ? content.getIntValue("apiversion") : 1;
        SQLFactory sqlFactory = new SQLFactory(this, "Api关联应用添加");
        sqlFactory.addParameter("sys_apiappsid", createTableID("sys_apiapps"));
        sqlFactory.addParameter("systemappid", systemappid);
        sqlFactory.addParameter("apiid", apiid);
        sqlFactory.addParameter("apiversion", apiversion);
        dbConnect.runSqlUpdate(sqlFactory.getSQL());
        return getSucReturnObject().toString();
    }

    @API(title = "应用api-应用关联Api删除", apiversion = R.ID10004101.v1.class)
    @CACHEING_CLEAN(cms = {@cm(clazz = apidoc.class, method = {"queryAppApiList"})})
    public String deleteAppApi() throws YosException {
        long sys_apiappsid = content.getLong("sys_apiappsid");
        dbConnect.runSqlUpdate("delete from sys_apiapps where sys_apiappsid=" + sys_apiappsid);
        return getSucReturnObject().toString();
    }

    @API(title = "应用api-Api文档更新", apiversion = R.ID10004201.v1.class)
    @CACHEING_CLEAN(cms = {@cm(clazz = apidoc.class, method = {"queryAppApiList", "queryAppList"})})
    public String updateApiDoc() throws YosException {
        long apiid = content.getLongValue("apiid");
        int apiversion = content.getIntValue("apiversion");

        JSONObject requestjson = null;
        try {
            requestjson = JSONObject.parseObject(content.getString("requestjson", true), Feature.OrderedField);
        } catch (Exception e) {
            return getErrReturnObject().setErrMsg("请求内容不是有效的JSONObject格式").toString();
        }
        JSONObject responsejson;
        try {
            responsejson = JSONObject.parseObject(content.getString("responsejson"), Feature.OrderedField);
        } catch (Exception e) {
            return getErrReturnObject().setErrMsg("响应内容不是有效的JSONObject格式").toString();
        }

        String requestnotes = content.getString("requestnotes");
        String responsenotes = content.getString("responsenotes");

        if (dbConnect.runSqlQuery("select * from sys_apidoc where apiid='" + apiid + "' and apiversion='" + apiversion + "'").isEmpty()) {
            SQLFactory sqlFactory = new SQLFactory(this, "Api文档新增");
            sqlFactory.addParameter("sys_apidocid", createTableID("sys_apidoc"));
            sqlFactory.addParameter("apiid", apiid);
            sqlFactory.addParameter("apiversion", apiversion);
            sqlFactory.addParameter("requestjson", requestjson.toJSONString());
            sqlFactory.addParameter("requestnotes", requestnotes);
            sqlFactory.addParameter("responsejson", responsejson.toJSONString());
            sqlFactory.addParameter("responsenotes", responsenotes);
            sqlFactory.addParameter("changeuserid", userid);
            dbConnect.runSqlUpdate(sqlFactory.getSQL());
        } else {
            dbConnect.runSqlUpdate("update sys_apidoc set changedate=now(),changeuserid='" + userid + "', requestjson='" + requestjson.toJSONString() + "',requestnotes='" + requestnotes + "', responsejson='" + responsejson.toJSONString() + "',responsenotes='" + responsenotes + "' where apiid='" + apiid + "' and apiversion='" + apiversion + "'");
        }
        return getSucReturnObject().toString();
    }
}
